.. _renesas-ra_general:

General information about Renesas RA port
=========================================

Overview
--------

The renesas-ra port supports boards powered by Renesas Electronics's
the flexible Renesas Advanced (RA) 32-bit microcontrollers (MCUs) family,
industry-leading 32-bit MCUs with the Arm® Cortex®-M33, -M23 and -M4
processor cores and PSA certification.

The ported hardware functionalities are Pin, SPI, I2C, UART and RTC at this present.
Other hardware functionalities such as Timer, PWM, USB, CAN and WDT are not implemented yet.

The following boards are officially supported.

* RA4M1-CLICKER

For the manual and other references for the board and RA Family MCU, please refer to the web page: `RA4M1 CLICKER <https://www.mikroe.com/ra4m1-clicker>`_

* EK-RA6M2

For the manual and other references for the board and RA Family MCU, please refer to the web page: `EK-RA6M2 <https://www.renesas.com/products/microcontrollers-microprocessors/ra-cortex-m-mcus/ek-ra6m2-ra6m2-mcu-group-evaluation-board>`_

The following boards are unofficially supported.

* EK-RA4M1

For the manual and other references for the board and RA Family MCU, please refer to the web page: `EK-RA4M1 <https://www.renesas.com/products/microcontrollers-microprocessors/ra-cortex-m-mcus/ek-ra4m1-ra4m1-mcu-group-evaluation-board>`_

* EK-RA4W1

For the manual and other references for the board and RA Family MCU, please refer to the web page: `EK-RA4W1 <https://www.renesas.com/products/microcontrollers-microprocessors/ra-cortex-m-mcus/ek-ra4w1-ra4w1-mcu-group-evaluation-board>`_

* EK-RA6M1

For the manual and other references for the board and RA Family MCU, please refer to the web page: `EK-RA6M1 <https://www.renesas.com/products/microcontrollers-microprocessors/ra-cortex-m-mcus/ek-ra6m1-ra6m1-mcu-group-evaluation-board>`_

For more information, please visit the web page: `<https://github.com/renesas/micropython/wiki>`_

